@@ -980,12 +980,17 @@ class ModelTerms:
         for k, v in components.items():
             categoric = [k_ for k_, v_ in v.items() if v_ == "categoric"]
             numeric = [k_ for k_, v_ in v.items() if v_ == "numeric"]
+            # if it is an interaction both categoric and numeric terms...
             if categoric and numeric:
                 numeric_set = set(numeric)
+                numeric_part = ":".join(numeric)
                 if numeric_set not in numeric_group_sets:
                     numeric_group_sets.append(numeric_set)
                     numeric_groups.append(dict())
                 idx = numeric_group_sets.index(numeric_set)
+                # Prevent full encoding when numeric part is present outside this num/cat interaction
+                if numeric_part in components.keys():
+                    numeric_groups[idx][numeric_part] = []
                 numeric_groups[idx][k] = categoric
 
         return [categoric_group] + numeric_groups
